==> domain-cli-0.1.12.tgz: package/README.md <==
## domain-cli    ![openSource](https://badges.frapsoft.com/os/v1/open-source.svg?v=102)

<p align="center">
  <a target="_blank" href="https://github.com/WeiChiaChang/domain-cli">
    <img alt="domain-cli" src="https://i.imgur.com/JgpHLSA.gif">
  </a>
</p>
<p align=center>
  <a target="_blank" href="https://npmjs.org/package/domain-cli" title="NPM version"><img src="https://img.shields.io/npm/v/domain-cli.svg"></a>
  <a target="_blank" href="http://nodejs.org/download/" title="Node version"><img src="https://img.shields.io/badge/node.js-%3E=_7.0-green.svg"></a>
  <a target="_blank" href="https://opensource.org/licenses/MIT" title="License: MIT"><img src="https://img.shields.io/badge/License-MIT-blue.svg"></a>
  <a target="_blank" href="http://makeapullrequest.com" title="PRs Welcome"><img src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg"></a>
</p>

> Search domain names if registered or not in terminal

API & datas comes from [domainsdb](https://domainsdb.info/).

## Install
```shell
$ npm install domain-cli -g
```

## Usage
Type the following command in your terminal:
```shell
$ domain-cli
```

The interactive script will ask you:
```shell
Input domain names you wanna check if registered please (e.g. google.com)
```

Paste the domain name you wanna check if registered by others or not:
```shell
google.com
```

Here's the result:
<p align="center">
  <a target="_blank" href="https://github.com/WeiChiaChang/domain-cli">
    <img alt="domain-cli" src="https://i.imgur.com/3BFaLIi.png">
  </a>
</p>

## License
MIT © [WeiChiaChang](https://github.com/WeiChiaChang)

==> domain-cli-0.1.16.tgz: package/README.md <==
## domain-cli    ![openSource](https://badges.frapsoft.com/os/v1/open-source.svg?v=102)

<p align="center">
  <a target="_blank" href="https://github.com/WeiChiaChang/domain-cli">
    <img alt="domain-cli" src="https://i.imgur.com/JgpHLSA.gif">
  </a>
</p>
<p align=center>
  <a target="_blank" href="https://npmjs.org/package/domain-cli" title="NPM version"><img src="https://img.shields.io/npm/v/domain-cli.svg"></a>
  <a target="_blank" href="http://nodejs.org/download/" title="Node version"><img src="https://img.shields.io/badge/node.js-%3E=_7.0-green.svg"></a>
  <a target="_blank" href="https://opensource.org/licenses/MIT" title="License: MIT"><img src="https://img.shields.io/badge/License-MIT-blue.svg"></a>
  <a target="_blank" href="http://makeapullrequest.com" title="PRs Welcome"><img src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg"></a>
</p>

> Search domain names if registered or not in terminal

API & datas comes from [domainsdb](https://domainsdb.info/).

## Install
```shell
$ npm install domain-cli -g
```

## Usage
Type the following command in your terminal:
```shell
$ domain-cli
```

The interactive script will ask you:
```shell
Input domain names you wanna check if registered please (e.g. google.com)
```

Paste the domain name you wanna check if registered by others or not:
```shell
google.com
```

Here's the result:
<p align="center">
  <a target="_blank" href="https://github.com/WeiChiaChang/domain-cli">
    <img alt="domain-cli" src="https://i.imgur.com/EJ1cSD1.png">
  </a>
</p>

## License
MIT © [WeiChiaChang](https://github.com/WeiChiaChang)
